@@ -3,7 +3,7 @@ from datetime import datetime
 from typing import Optional
 
 from pydantic import BaseModel
-from aoi import AOI
+from .aoi import AOI
 
 
 
